@@ -356,7 +356,9 @@ def build2(javaEnv,dirs):
 
     local('cp config/keyset-%s.json deploy/worker/config/keyset.json' % javaEnv)
     local('cp config/logback.xml deploy/worker/config/')
+    local('cp config/application-%s.yml deploy/worker/config/' % javaEnv)
     local('cp config/application-%s-worker.yml deploy/worker/config/' % javaEnv)
+    local('cp config/initiate_shutdown.sql deploy/worker/config/')
 
     local('cp -r worker/target/lib/ deploy/worker/')
 
